summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/ownedcodeblock.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60 (patch)
treebabc4a761925023e16fa94633959f35d1c251887 /umbrello/umbrello/ownedcodeblock.h
parent0813b39aed2cf4c84157a22c4c9594336d93d412 (diff)
downloadtdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.tar.gz
tdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/ownedcodeblock.h')
-rw-r--r--umbrello/umbrello/ownedcodeblock.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/umbrello/umbrello/ownedcodeblock.h b/umbrello/umbrello/ownedcodeblock.h
index 130bd4dd..a911351b 100644
--- a/umbrello/umbrello/ownedcodeblock.h
+++ b/umbrello/umbrello/ownedcodeblock.h
@@ -29,7 +29,7 @@ class UMLObject;
/**
* class OwnedCodeBlock
* Describes any codeblock which is 'owned' by a UMLobject of some sort and should
* be in sync with that tqparent.
*/
class OwnedCodeBlock : virtual public TQObject
@@ -44,7 +44,7 @@ public:
/**
* Constructor
*/
- OwnedCodeBlock ( UMLObject * tqparent );
+ OwnedCodeBlock ( UMLObject * parent );
/**
* Empty Destructor
@@ -56,7 +56,7 @@ public:
*/
UMLObject * getParentObject ( );
// get the tqparent code document of this code block
virtual CodeDocument * getParentDocument ( ) = 0;
protected:
@@ -88,7 +88,7 @@ protected:
private:
- void initFields ( UMLObject * tqparent );
+ void initFields ( UMLObject * parent );
UMLObject * m_parentObject;
@@ -29,7 +29,7 @@ class UMLObject;
* class OwnedCodeBlock
* Describes any codeblock which is 'owned' by a UMLobject of some sort and should
- * be in sync with that tqparent.
+ * be in sync with that parent.
*/
class OwnedCodeBlock : virtual public TQObject
@@ -56,7 +56,7 @@ public:
*/
UMLObject * getParentObject ( );
- // get the tqparent code document of this code block
+ // get the parent code document of this code block
virtual CodeDocument * getParentDocument ( ) = 0;
protected: